pub struct DbSchema { /* private fields */ }Expand description
Schema metadata keyed by logical table name.
Implementations
Sourceimpl DbSchema
impl DbSchema
pub fn table(&self, logical_name: &str) -> Option<&DbTable>
Sourcepub fn table_name(&self, table: &str) -> Result<&str, OpenAuthError>
pub fn table_name(&self, table: &str) -> Result<&str, OpenAuthError>
Resolve a logical or physical table name to its physical database name.
Sourcepub fn field_name(
&self,
table: &str,
field: &str,
) -> Result<&str, OpenAuthError>
pub fn field_name( &self, table: &str, field: &str, ) -> Result<&str, OpenAuthError>
Resolve a logical or physical field name to its physical database column name.
Sourcepub fn field(&self, table: &str, field: &str) -> Result<&DbField, OpenAuthError>
pub fn field(&self, table: &str, field: &str) -> Result<&DbField, OpenAuthError>
Resolve field metadata from logical or physical table and field names.
pub fn tables(&self) -> impl Iterator<Item = (&str, &DbTable)>
pub fn insert_plugin_table( &mut self, logical_name: String, table: DbTable, ) -> Result<(), OpenAuthError>
pub fn insert_plugin_field( &mut self, table: &str, logical_name: String, field: DbField, ) -> Result<(), OpenAuthError>