Module plugin

Module plugin 

Plugin contracts for OpenAuth extensions.

Structs

AuthPlugin
PluginAfterHook
PluginAsyncAfterHook
PluginAsyncBeforeHook
PluginAsyncMiddleware
PluginBeforeHook
PluginDatabaseHook
Executable database hook registered by a plugin.
PluginDatabaseHookContext
Runtime metadata passed to executable database hooks.
PluginEndpointHooks
PluginErrorCode
Error code contributed by a plugin.
PluginHookMatcher
Matcher used to select endpoint hooks.
PluginInitOutput
Typed, additive output from a plugin init handler.
PluginMiddleware
PluginMigration
Plugin migration metadata.
PluginPasswordValidationInput
PluginPasswordValidationRejection
PluginPasswordValidator
PluginRateLimitRule
Rate-limit rule contributed by a plugin.

Enums

PluginAfterHookAction
Action returned by an after endpoint hook.
PluginBeforeHookAction
Action returned by a before endpoint hook.
PluginDatabaseAfterInput
Query and adapter result passed to a database hook after the operation runs.
PluginDatabaseBeforeAction
Action returned by a before hook.
PluginDatabaseBeforeInput
Query passed to a database hook before the adapter operation runs.
PluginDatabaseOperation
Mutating database operations that can be observed by plugins.
PluginRequestAction
PluginSchemaContribution
Database schema contribution made by a plugin.

Type Aliases

PluginAfterHookFuture
PluginAfterHookHandler
PluginAsyncAfterHookHandler
PluginAsyncBeforeHookHandler
PluginAsyncMiddlewareHandler
PluginBeforeHookFuture
PluginBeforeHookHandler
PluginBody
PluginDatabaseAfterHookHandler
PluginDatabaseBeforeHookHandler
PluginEndpoint
Async endpoint contributed by a plugin.
PluginInitHandler
PluginMiddlewareFuture
PluginMiddlewareHandler
PluginOnRequest
PluginOnResponse
PluginPasswordValidatorFuture
PluginPasswordValidatorHandler
PluginRequest
PluginResponse