Plugin contracts for OpenAuth extensions.
Structs
- Auth
Plugin - Plugin
After Hook - Plugin
Async After Hook - Plugin
Async Before Hook - Plugin
Async Middleware - Plugin
Before Hook - Plugin
Database Hook - Executable database hook registered by a plugin.
- Plugin
Database Hook Context - Runtime metadata passed to executable database hooks.
- Plugin
Endpoint Hooks - Plugin
Error Code - Error code contributed by a plugin.
- Plugin
Hook Matcher - Matcher used to select endpoint hooks.
- Plugin
Init Output - Typed, additive output from a plugin init handler.
- Plugin
Middleware - Plugin
Migration - Plugin migration metadata.
- Plugin
Password Validation Input - Plugin
Password Validation Rejection - Plugin
Password Validator - Plugin
Rate Limit Rule - Rate-limit rule contributed by a plugin.
Enums
- Plugin
After Hook Action - Action returned by an after endpoint hook.
- Plugin
Before Hook Action - Action returned by a before endpoint hook.
- Plugin
Database After Input - Query and adapter result passed to a database hook after the operation runs.
- Plugin
Database Before Action - Action returned by a before hook.
- Plugin
Database Before Input - Query passed to a database hook before the adapter operation runs.
- Plugin
Database Operation - Mutating database operations that can be observed by plugins.
- Plugin
Request Action - Plugin
Schema Contribution - Database schema contribution made by a plugin.
Type Aliases
- Plugin
After Hook Future - Plugin
After Hook Handler - Plugin
Async After Hook Handler - Plugin
Async Before Hook Handler - Plugin
Async Middleware Handler - Plugin
Before Hook Future - Plugin
Before Hook Handler - Plugin
Body - Plugin
Database After Hook Handler - Plugin
Database Before Hook Handler - Plugin
Endpoint - Async endpoint contributed by a plugin.
- Plugin
Init Handler - Plugin
Middleware Future - Plugin
Middleware Handler - Plugin
OnRequest - Plugin
OnResponse - Plugin
Password Validator Future - Plugin
Password Validator Handler - Plugin
Request - Plugin
Response